cgexplore.molecular.VaBeneGenerator
===================================

.. currentmodule:: cgexplore.molecular

.. autoclass:: VaBeneGenerator
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~VaBeneGenerator.get_precursors
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~VaBeneGenerator.present_beads
      ~VaBeneGenerator.num_beads
      ~VaBeneGenerator.seed
      ~VaBeneGenerator.binder_beads
      ~VaBeneGenerator.placer_beads
      ~VaBeneGenerator.scale
   
   